
# About
The Python Package Index Project (pypipr)

pypi : https://pypi.org/project/pypipr


# Setup
Install with pip
```
pip install pypipr
```

Then import pypipr
```python
import pypipr
```

# CONSTANT

`LINUX`

`WINDOWS`
